@@ -29,16 +29,6 @@ use strict;
 use warnings;
 
 our %EXPORT_TAGS = (
-#	all => [
-##		qw(register hook_server hook_command),
-#		qw(hook_print hook_timer unhook print command),
-#		qw(find_context get_context set_context),
-#		qw(get_info get_prefs emit_print nickcmp),
-#		qw(get_list context_info strip_code),
-#		qw(PRI_HIGHEST PRI_HIGH PRI_NORM PRI_LOW),
-#		qw(PRI_LOWEST EAT_NONE EAT_XCHAT EAT_PLUGIN),
-#		qw(EAT_ALL KEEP REMOVE),
-#	],
 	constants => [
 		qw(PRI_HIGHEST PRI_HIGH PRI_NORM PRI_LOW PRI_LOWEST), # priorities
 		qw(EAT_NONE EAT_XCHAT EAT_PLUGIN EAT_ALL), # callback return values
@@ -112,7 +102,7 @@ sub hook_command {
 
 	$callback = Xchat::Embed::fix_callback( $package, $callback );
 	
-	my ($priority, $help_text, $data) = ( Xchat::PRI_NORM, '', undef );
+	my ($priority, $help_text, $data) = ( Xchat::PRI_NORM, undef, undef );
 	
 	if( ref( $options ) eq 'HASH' ) {
 		if( exists( $options->{priority} ) && defined( $options->{priority} ) ) {
@@ -244,7 +234,7 @@ sub unhook {
 
 sub print {
 	my $text = shift @_;
-	return 1 unless defined $text;
+	return "" unless defined $text;
 	if( ref( $text ) eq 'ARRAY' ) {
 		if( $, ) {
 			$text = join $, , @$text;
@@ -265,7 +255,7 @@ sub print {
 			Xchat::set_context( $old_ctx );
 			return 1;
 		} else {
-			return 0;
+			return "";
 		}
 	} else {
 		Xchat::Internal::print( $text );
@@ -285,6 +275,7 @@ sub printf {
 
 sub command {
 	my $command = shift;
+	return "" unless defined $command;
 	my @commands;
 	
 	if( ref( $command ) eq 'ARRAY' ) {
@@ -303,7 +294,7 @@ sub command {
 			Xchat::set_context( $old_ctx );
 			return 1;
 		} else {
-			return 0;
+			return "";
 		}
 	} else {
 		Xchat::Internal::command( $_ ) foreach @commands;
@@ -346,7 +337,7 @@ sub get_info {
 }
 
 sub user_info {
-	my $nick = shift @_ || Xchat::get_info( "nick" );
+	my $nick = Xchat::strip_code(shift @_ || Xchat::get_info( "nick" ));
 	my $user;
 	for (Xchat::get_list( "users" ) ) {
 		if ( Xchat::nickcmp( $_->{nick}, $nick ) == 0 ) {
