@@ -44,6 +44,10 @@ list_addentry (GSList ** list, char *cmd, char *name)
 	struct popup *pop;
 	int cmd_len = 1, name_len;
 
+	/* remove <2.8.0 stuff */
+	if (!strcmp (cmd, "AWAY") & !strcmp (name, "BACK"))
+		return;
+
 	if (cmd)
 		cmd_len = strlen (cmd) + 1;
 	name_len = strlen (name) + 1;
@@ -331,7 +335,7 @@ char *
 get_xdir_utf8 (void)
 {
 	if (!xdir_utf)	/* never free this, keep it for program life time */
-		xdir_utf = g_filename_to_utf8 (get_xdir_fs (), -1, 0, 0, 0);
+		xdir_utf = xchat_filename_to_utf8 (get_xdir_fs (), -1, 0, 0, 0);
 
 	return xdir_utf;
 }
@@ -430,6 +434,9 @@ const struct prefs vars[] = {
 	{"gui_slist_skip", P_OFFINT (slist_skip), TYPE_BOOL},
 	{"gui_throttlemeter", P_OFFINT (throttlemeter), TYPE_INT},
 	{"gui_topicbar", P_OFFINT (topicbar), TYPE_BOOL},
+	{"gui_tray", P_OFFINT (gui_tray), TYPE_BOOL},
+	{"gui_tray_blink", P_OFFINT (gui_tray_blink), TYPE_INT},
+	{"gui_tray_flags", P_OFFINT (gui_tray_flags), TYPE_INT},
 	{"gui_ulist_buttons", P_OFFINT (userlistbuttons), TYPE_BOOL},
 	{"gui_ulist_doubleclick", P_OFFSET (doubleclickuser), TYPE_STR},
 	{"gui_ulist_hide", P_OFFINT (hideuserlist), TYPE_BOOL},
@@ -455,7 +462,8 @@ const struct prefs vars[] = {
 	{"input_beep_msg", P_OFFINT (beepmsg), TYPE_BOOL},
 	{"input_command_char", P_OFFSET (cmdchar), TYPE_STR},
 	{"input_filter_beep", P_OFFINT (filterbeep), TYPE_BOOL},
-	{"input_flash_hilight", P_OFFINT (flash_hilight), TYPE_BOOL},
+	{"input_flash_hilight", P_OFFINT (input_flash_hilight), TYPE_BOOL},
+	{"input_flash_priv", P_OFFINT (input_flash_priv), TYPE_BOOL},
 	{"input_perc_ascii", P_OFFINT (perc_ascii), TYPE_BOOL},
 	{"input_perc_color", P_OFFINT (perc_color), TYPE_BOOL},
 
@@ -647,9 +655,11 @@ load_config (void)
 	prefs.autoopendccchatwindow = 1;
 	prefs.userhost = 1;
 	prefs.gui_url_mod = 4;	/* ctrl */
+	prefs.gui_tray = 1;
+	prefs.gui_tray_blink = 0xfc920; /* 1111 1100 1001 0010 0000 */
 	prefs.mainwindow_save = 1;
 	prefs.bantype = 2;
-	prefs.flash_hilight = 1;
+	prefs.input_flash_priv = prefs.input_flash_hilight = 1;
 	prefs.autodccsend = 2;	/* browse mode */
 #ifdef WIN32
 	prefs.identd = 1;
@@ -892,18 +902,18 @@ cmd_set (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 	int idx = 2;
 	char *var, *val;
 
-	if (strcasecmp (word[2], "-quiet") == 0)
-	{
-		idx++;
-		quiet = TRUE;
-	}
-
 	if (strcasecmp (word[2], "-e") == 0)
 	{
 		idx++;
 		erase = TRUE;
 	}
 
+	if (strcasecmp (word[idx], "-quiet") == 0)
+	{
+		idx++;
+		quiet = TRUE;
+	}
+
 	var = word[idx];
 	val = word_eol[idx+1];
 
