@@ -114,7 +114,7 @@ mask_edited (GtkCellRendererText *render, gchar *path, gchar *new, gpointer dat)
 	if (!strcmp (old, new))	/* no change */
 		;
 	else if (ignore_exists (new))	/* duplicate, ignore */
-		gtkutil_simpledialog (_("That mask already exists."));
+		fe_message (_("That mask already exists."), FE_MSG_ERROR);
 	else
 	{
 		/* delete old mask, and add new one with original flags */
@@ -260,7 +260,7 @@ ignore_store_new (int cancel, char *mask, gpointer data)
 	/* check if it already exists */
 	if (ignore_exists (mask))
 	{
-		gtkutil_simpledialog (_("That mask already exists."));
+		fe_message (_("That mask already exists."), FE_MSG_ERROR);
 		return;
 	}
 
@@ -351,7 +351,7 @@ ignore_gui_open ()
 	}
 
 	ignorewin =
-			  mg_create_generic_tab ("ignorelist", _("X-Chat: Ignore list"),
+			  mg_create_generic_tab ("IgnoreList", _("XChat: Ignore list"),
 											FALSE, TRUE, close_ignore_gui_callback,
 											NULL, 600, 256, &vbox, 0);
 
@@ -381,7 +381,7 @@ ignore_gui_open ()
 	gtk_widget_show (box);
 
 	gtkutil_button (box, GTK_STOCK_NEW, 0, ignore_new_entry_clicked, 0,
-						 _("Add"));
+						 _("Add..."));
 	gtkutil_button (box, GTK_STOCK_DELETE, 0, ignore_delete_entry_clicked,
 						 0, _("Delete"));
 	gtkutil_button (box, GTK_STOCK_CLEAR, 0, ignore_clear_entry_clicked,
